#!/usr/bin/python
# -*- coding: UTF-8 -*-

############################################################
#                                                          #
#  Utilitaire de configuration des messages pour bacula    #
#  génère le fichier /etc/bacula/eolemsgdefs.pic           #
#  et le fichier /etc/bacula/eolemessages.conf             #
#                                                          #
#  licence CECILL                                          #
#                                                          #
#  Klaas TJEBBES klaas.tjebbes@ac-dijon.fr                 #
#                                                          #
############################################################

import os
import sys
import getopt
import pickle
from creole import parsedico

class baculamsg:
    """
    renseigne le fichier eolemessages.conf avec
    MailOnError = 'mail'
    Mail = 'mailok'
    Possibilité de specifier un expediteur dans gen_config
    * Utilise un fichier pickle pour stocker et retrouver
      les valeurs pour affichage
    """
    def __init__(self):
        self.dfich = '/etc/bacula/eolemsgdefs.pic'
        self.conff = '/etc/bacula/eolemessages.conf'
        self.dico = {'mail': '',
                     'mailok': '',
                     'smtp': '',
                     'bacula_mail_from': '',
                     'system_mail_from': '',
                     'nom_domaine_local': '',
                     'nom_machine': '',
                     'numero_etab': ''
                     }
        self.d_eole = parsedico.parse_dico()
        self.chargedico()

    def chargedico(self):
        """charge le dictionnaire contenant les informations :
            serveur smtp, adresse mail
        """
        try:
            self.dico.update(pickle.load(file(self.dfich, 'r')))
        except:
            pass
        # il pourrait y avoir 'mail' et 'smtp' déjà renseigné dans le dictionnaire eole
        # donc on ne ".update" pas
        for i in ['nom_domaine_local', 'nom_machine', 'numero_etab', 'system_mail_from', 'bacula_mail_from']:
            if not self.d_eole.has_key(i): continue
            self.dico[i] = self.d_eole[i]

    def get_mail_ok(self):
        return self.dico['mailok']

    def get_mail_err(self):
        return self.dico['mail']

    def get_smtp(self):
        if self.dico['smtp']:
            return self.dico['smtp']
        if self.d_eole.has_key('passerelle_smtp'):
            return self.d_eole['passerelle_smtp']
        if self.d_eole.has_key('passerelle_smtp_aca'):
            return self.d_eole['passerelle_smtp_aca']

    def affiche(self):
        """affiche serveur_smtp;adresse_mail;adresse_mailok
        rien si vide
        """
        msg = ''
        if self.get_smtp(): msg += '%s'%self.get_smtp()
        msg += ';'
        if self.get_mail_err(): msg += '%s'%self.get_mail_err()
        msg += ';'
        if self.get_mail_ok(): msg += '%s'%self.get_mail_ok()
        return msg

    def delmail(self):
        """supprime les données du dictionnaire et vide le fichier /etc/bacula/eolemessages.conf
        """
        self.dico = {'mail': '', 'mailok': '', 'smtp': ''}
        self.savedico()
        self.applique_conf()

    def set_conf(self, mail, mailok, smtp): #, expediteur):
        """renseigne la configuration
        """
        self.dico['mail'] = mail
        self.dico['mailok'] = mailok
        self.dico['smtp'] = smtp
#        self.dico['expediteur'] = expediteur
        self.savedico()
        self.applique_conf()

    def savedico(self):
        """enregistre le dictionnaire après modification
        """
        pickle.dump(self.dico,file(self.dfich, 'w'))

    def applique_conf(self):
        """Ecrit le fichier de configuration
        """
        # certain mail refuse les expéditeur d'un domaine inconnu (ex : domain.lan)
        # on prend le domaine du premier mail ou la valeur de "system_mail_from"
        if self.dico['mail'] or self.dico['mailok']:
            if self.dico['bacula_mail_from']:
                self.dico['expediteur'] = self.dico['bacula_mail_from']
            elif self.dico['system_mail_from']:
                self.dico['expediteur'] = self.dico['system_mail_from']
            else:
                self.dico['expediteur'] = 'bacula-%s@%s'%(self.dico['nom_machine'], self.dico['nom_domaine_local'])
            try:
                tmpl ="""mailcommand = "/usr/share/eole/bacula/envoiemessage.py -8 -h %(smtp)s -f %(expediteur)s -s \\"%(numero_etab)s sauvegarde %(nom_machine)s.%(nom_domaine_local)s : %%e\\" %%r"\n"""%self.dico
            except:
                tmpl = ''
            if self.dico['mail']:
                tmpl +="""MailOnError = %s = all\n""" % self.dico['mail']
            if self.dico['mailok']:
                tmpl +="""Mail = %s = all\n""" % self.dico['mailok']
        else: tmpl = '' # pas de mail du tout
        file(self.conff, 'w').write(tmpl)
        os.system('echo reload | bconsole -c /etc/bacula/bconsole.conf > /dev/null')

def main():
    bmsg = baculamsg()
    # gestion des options
    mail, mailok, servsmtp = '', '', ''
#    expediteur = ''
    try:
        options, args = getopt.getopt(sys.argv[1:],'e:s:m:o:dla',
        ['expediteur=',
        'servsmtp=',
        'mail=',
        'mailok=',
        'delete',
        'liste',
        'applique'])

    except getopt.GetoptError:
        er_type, er_value, er_traceback = sys.exc_info()
        er_msg = str(er_value)
        sys.exit("l'option -%s est inconnue ou nécessite un argument" % er_msg[er_msg.index('-')+1])

    for (opt,val) in options:
        # par quel expéditeur
#        if (opt == '-e') or (opt == '--expediteur'):
#            expediteur = val.strip()
        # par quel SMTP envoyer les mails
        if (opt == '-s') or (opt == '--servsmtp'):
            servsmtp = val.strip()
        # à quelle adresse svp ?
        if (opt == '-m') or (opt == '--mail'):
            mail = val.strip()
        # mailok
        if (opt == '-o') or (opt == '--mailok'):
            mailok = val.strip()
        # desactivation
        if (opt == '-d') or (opt == '--delete'):
            bmsg.delmail()
            return
        # listing
        if (opt == '-l') or (opt == '--liste'):
            print bmsg.affiche()
            return
        # application de la configuration
        if (opt == '-a') or (opt == '--applique'):
            bmsg.applique_conf()
            return

    # renseigne le fichier /etc/bacula/eolemessages.conf
    if ( mail or mailok ):
        if not servsmtp:
            if bmsg.get_smtp():
                servsmtp = bmsg.get_smtp()
            else:
                sys.exit("Aucun serveur SMTP renseigné")
        bmsg.set_conf(mail, mailok, servsmtp) #, expediteur)
        return 0
    else:
        sys.exit("""
        options possibles :
            -s (--servsmtp)  Serveur SMTP à utiliser
            -m (--mail)      Adresse mail en cas d'erreur
            -o (--mailok)    Adresse mail pour chaque sauvegarde (réussie et échouée)
            -d (--delete)    Désactiver l'envoie de mail
            -l (--liste)     Lister les mails configurés
            -a (--applique)  Appliquer la modification, ne devrait pas être utilisé
            """)

if __name__ == "__main__":
    main()

