#!/bin/bash

# Ces variables doivent être identiques à celles
# dans la section "__init__(self)" de
# /etc/bacula/scripts/DirStartUp.py
REPERTOIRE='/var/sauvegardes'
VERSION=`cat /etc/eole/version`
MODULE=`echo $VERSION | cut -d '-' -f 1`
TEMOIN='/var/www/ead/tmp/temoin-bacula'
EADRESULT='/var/www/ead/tmp/resultat-bacula'
EADRAPPORT='/var/www/ead/tmp/rapport-bacula.txt'
LOCKNAME='eolesauvegarde'
QUOTASCRIPT='/usr/share/eole/bacula/restore_quotas.py'

# Initialisation des variables nommées en fonction du module
if [ $MODULE == "horus" -o $MODULE == "scribe" ]
then
    SIDSAVEFILE=/etc/eole/${MODULE}_SID
fi
if [ $MODULE == "horus" ]
then
    LDAPSAVFILE=/data/sauv_ldap.ldif
    MYSQLSAVFILE=/data/sauv_mysql.sql
    QUOTASAVFILE=/data/sauv_quota.txt
    JABBERDSAVFILE=/data/ejabberd.bak
#    ACLSAVFILE=/data/sauv_acl.txt
else
    LDAPSAVFILE=/home/sauv_ldap.ldif
    MYSQLSAVFILE=/home/sauv_mysql.sql
    QUOTASAVFILE=/home/sauv_quota.txt
#    ACLSAVFILE=/home/sauv_acl.txt
    JABBERDSAVFILE=/home/ejabberd.bak
fi

# pour que l'affichage de [ ok ] soit ok
export TERM='dumb'

. ParseDico

#    Main
if [ -x /usr/share/eole/FonctionsEoleNg ]
then
	. /usr/share/eole/FonctionsEoleNg
else
	echo 'Erreur : FonctionsEoleNg non trouvé'
	exit 1
fi

# Fonction Diverses
testlock(){
	echo "Test des locks"
	CheckAllLocks
}

addlock(){
	testlock
	echo "Ajout du verrou (lock) \"$LOCKNAME\""
	AddLock $LOCKNAME
}

dellock(){
	echo "Suppression du verrou (lock) \"$LOCKNAME\""
	DelLock $LOCKNAME
}

testcmd(){
    [ "$1" -ne "0" ] && exit 1
}

servicestop(){
    [ -f /etc/bacula/DO_NOT_STOP_SERVICES_DURING_BACKUP ] && return 0
    if [ $MODULE == "eclair" ];then
	    echo "Pas de services a arreter"
	    return 0
    fi
    [ -e /etc/init.d/samba ] &&  /etc/init.d/samba stop
    # LDAP démarré pendant la sauvegarde
    #[ -e /etc/init.d/slapd ] &&  /etc/init.d/slapd stop
    if [ "$ftp_perso" != "non" ]
    then
	    [ -e /etc/init.d/proftpd ] &&  /etc/init.d/proftpd stop
    fi
    [ -e /etc/init.d/sympa ] &&  /etc/init.d/sympa stop
}

servicestart(){
    [ -f /etc/bacula/DO_NOT_STOP_SERVICES_DURING_BACKUP ] && return 0
    if [ $MODULE == "eclair" ];then
	    echo "Pas de services a demarrer"
	    return 0
    fi
    [ -e /etc/init.d/samba ] &&  /etc/init.d/samba start
    # LDAP démarré pendant la sauvegarde
    #[ -e /etc/init.d/slapd ] &&  /etc/init.d/slapd start
    if [ "$ftp_perso" != "non" ]
    then
	    [ -e /etc/init.d/proftpd ] &&  /etc/init.d/proftpd start
    fi
    [ -e /etc/init.d/sympa ] &&  /etc/init.d/sympa start
    # parce qu'il ne suppporte pas l'arrêt de LDAP ...
    if [ "$sso" != "non" ]
    then
	    [ -e /etc/init.d/eole-sso ] &&  /etc/init.d/eole-sso restart
    fi
}

createsavefile(){
    FILENAME=$1
    touch $FILENAME
    chown root: $FILENAME
    chmod 400 $FILENAME
}

rotatefile(){
    FILENAME=$1
    [ -e ${FILENAME}.2 ] && {
    /bin/rm -f ${FILENAME}.3
    /bin/mv ${FILENAME}.2 ${FILENAME}.3
    }
    [ -e ${FILENAME}.1 ] && {
    /bin/mv ${FILENAME}.1 ${FILENAME}.2
    }
    [ -e ${FILENAME} ] && {
    /bin/mv ${FILENAME} ${FILENAME}.1
    }
}

prebackuppkg(){
	if [ $MODULE == "eclair" ]
	then
		rm -f /home/sauv_paquet.txt
		createsavefile /home/sauv_paquet.txt
		dpkg --get-selections > /home/sauv_paquet.txt
	fi
}

postbackuppkg(){
	if [ $MODULE == "eclair" ]
	then
		rm -f /home/sauv_paquet.txt
	fi
}

##############
# Sauvegarde #
##############

##########
## LDAP ##
prebackupldap(){
    if [ $MODULE == "eclair" ];then
	    exit 0
    fi
    /etc/init.d/slapd stop
    # Sauvegarde LDAP, LDAP fonctionnant pendant la sauvegarde l'accélère
    rm -rf $LDAPSAVFILE
    DF=`df -Pm /home/|tail -n1|awk '{print $4}'`
    DU=`du -sm /var/lib/ldap/|awk '{print $1}'`
    if [ "$DF" -gt "$DU" ]
    then
	    createsavefile $LDAPSAVFILE
	    slapcat -v > $LDAPSAVFILE
    else
	    echo "Espace insuffisant sur /home ($DF Mo) pour sauvegarder LDAP, Abandon."
	    exit 1
    fi
    /etc/init.d/slapd start
}

postbackupldap(){
    # Suppression de la sauvegarde LDAP
    rm -rf $LDAPSAVFILE
}

###########
## MySQL ##
savmysql(){
    rm -f $MYSQLSAVFILE
    PASS=`/usr/bin/pwgen -1`
    /usr/share/eole/mysql_pwd.py "$PASS" nomodif >/dev/null
    createsavefile $MYSQLSAVFILE
    mysqldump -uroot -p$PASS --all-databases --flush-privileges --create-options -Q -c --lock-tables > $MYSQLSAVFILE
}

prebackupmysql(){
    if [ $MODULE == "horus" -a "$mysql" == "oui" ];then
	# Horus avec Mysql activé
	savmysql
    elif [ $MODULE == "scribe" ];then
	# Scribe
	savmysql
    else
        # autres cas
	exit 0
    fi
}

postbackupmysql(){
    if [ "$mysql" == "non" -o $MODULE == "eclair" ]
    then
	    exit 0
    fi
    # Suppression de la sauvegarde MySQL
    rm -f $MYSQLSAVFILE
}

############
## Quotas ##
prebackupquota(){
    if [ $MODULE == "eclair" ]
    then
	    exit 0
    fi
    /usr/sbin/repquota -a > $QUOTASAVFILE
}

postbackupquota(){
    if [ $MODULE == "eclair" ]
    then
	    exit 0
    fi
    # Suppression de la sauvegarde des quotas
    rm -f $QUOTASAVFILE
}

#############
### Acl ##
#prebackupacl(){
#    if [ $MODULE == "eclair" ]
#    then
#	    exit 0
#    fi
#    if [ $MODULE == "horus" ]
#    then
#        getfacl --absolute-names -PR /data > $ACLSAVFILE
#    else
#        getfacl --absolute-names -PR /home > $ACLSAVFILE
#    fi
#}
#
#postbackupacl(){
#    if [ $MODULE == "eclair" ]
#    then
#	    exit 0
#    fi
#    # Suppression de la sauvegarde des quotas
#    rm -f $ACLSAVFILE
#}

##############
## Ejabberd ##
prebackupejabberd(){
    if [ "$ejabberd" == "oui" ];then
	ejabberdctl status &>/dev/null
	if [ $? -eq 0 ];then
            ejabberdctl backup ejabber.bak
	    mv /var/lib/ejabberd/ejabber.bak $JABBERDSAVFILE
	else
            echo "ejabberd est arrêté : impossible de sauvegarder sa base"
	fi
    fi
    exit 0
}

postbackupejabberd(){
    if [ -f $JABBERDSAVFILE ];then
        rm -f $JABBERDSAVFILE
    fi
    exit 0
}

##############
## Fichiers ##
prebackup(){
    touch $TEMOIN
    touch $EADRAPPORT
    chmod 644 $EADRAPPORT

    # Montage du support de sauvegarde
    /usr/share/eole/bacula/montage.sh pre
    testcmd $?

    # Commandes perso
    [ -e /etc/bacula/precommandes ] && sh /etc/bacula/precommandes

    # Sauvegarde du SID
    if [ "$SIDSAVEFILE" != "" ]
    then
	    net getlocalsid | awk -F: '{print $2}' | awk -F " " '{print $1}'>$SIDSAVEFILE
    fi

    # Arrêt des services
    servicestop

    # sauvegarde de la liste des paquets installés
    prebackuppkg

    exit 0
}

postbackup(){
    # sauvegarde de la liste des paquets installés
    postbackuppkg
    # Suppression du fichier contenant le SID
    if [ "$SIDSAVEFILE" != "" ]
    then
        rm -rf $SIDSAVEFILE
    fi
    # Suppression de la sauvegarde LDAP
    rm -rf $LDAPSAVFILE
    # Sauvegarde de la configuration du serveur
    cp /etc/eole/config.eol $REPERTOIRE/$VERSION-config.eol -f

    # Commandes perso
    [ -e /etc/bacula/postcommandes ] && sh /etc/bacula/postcommandes
    # Redémarrage des services
    servicestart
    echo "Dernière sauvegarde effectuée le `date`." > $EADRESULT
    chmod 644 $EADRESULT
    /usr/share/eole/bacula/montage.sh post
    rm $TEMOIN -f
    exit 0
}

postbackuperr(){
    # En cas de plantage de la sauvegarde
    echo "La sauvegarde a échoué `date`." > $EADRESULT
    chmod 644 $EADRESULT
    # La sauvegarde ne s'est pas lancé, probablement
    # parce qu'un autre lock est présent
    [ ! -e $TEMOIN ] && exit 0
    # Redémarrage des services
    servicestart
    # Démontage
    /usr/share/eole/bacula/montage.sh post
    rm $TEMOIN -f
    exit 0
}

####################
## Catalog Bacula ##
precatalog(){
    touch $TEMOIN
    # Montage du support de sauvegarde
    /usr/share/eole/bacula/montage.sh pre
    testcmd $?
    # Création et copie du .sql
    /etc/bacula/scripts/make_catalog_backup bacula bacula
    rotatefile $REPERTOIRE/$VERSION-bacula.sql
    cp /var/lib/bacula/bacula.sql $REPERTOIRE/$VERSION-bacula.sql -f
}

postcatalog(){
    # Effacement du .sql
    /etc/bacula/scripts/delete_catalog_backup
    # Démontage du support
    /usr/share/eole/bacula/montage.sh post
    rm $TEMOIN -f
    exit 0
}

postcatalogerr(){
    # La sauvegarde ne s'est pas lancé, probablement
    # parce qu'un autre lock est présent
    [ ! -e $TEMOIN ] && exit 0
    postcatalog
}

################
# Restauration #
################
prerestoreall(){
    [ -e /etc/init.d/samba ] &&  /etc/init.d/samba stop
    [ -e /etc/init.d/mysql ] &&  /etc/init.d/mysql stop
    [ -e /etc/init.d/sympa ] &&  /etc/init.d/sympa stop
    exit 0
}

## LDAP ##
postrestoreldap(){
    # Restauration LDAP

    if [ -e $LDAPSAVFILE ]
    then
        /etc/init.d/slapd stop
        rm -rf /var/lib/ldap/*.*
        slapadd  -l $LDAPSAVFILE
        chown openldap:openldap /var/lib/ldap/ -R
        rm -rf $LDAPSAVFILE
        sleep 5
        /etc/init.d/slapd start
    fi
    echo
    echo "*** Restauration LDAP terminée ***"
    echo
}

## MySQL ##
restomysql(){
    PASS=`/usr/bin/pwgen -1`
    /usr/share/eole/mysql_pwd.py "$PASS" nomodif >/dev/null
    mysql -uroot -p$PASS < $MYSQLSAVFILE
    [ -e $MYSQLSAVFILE ] && /bin/rm $MYSQLSAVFILE
}

postrestoremysql(){
    if [ $MODULE == "horus" -a "$mysql" == "oui" ];then
	# Horus avec Mysql activé
	restomysql
    elif [ $MODULE == "scribe" ];then
	# Scribe
	restomysql
    else
        # autres cas
	exit 0
    fi
}

## Quotas ##
postrestorequota(){
    if [ -f $QUOTASAVFILE -a -x $QUOTASCRIPT ];then
	# les quotas ont été sauvegardés
	$QUOTASCRIPT $QUOTASAVFILE
    else
        # autres cas
    	exit 0
    fi
}

### Acls ##
#postrestoreacl(){
#    if [ -f $ACLSAVFILE ];then
#	# les acl ont été sauvegardés
#	setfacl -P --restore=$ACLSAVFILE
#    else
#        # autres cas
#    	exit 0
#    fi
#}

## Ejabberd ##
postrestoreejabberd(){
    if [ -f $JABBERDSAVFILE ];then
	ejabberdctl status &>/dev/null
	if [ $? -eq 0 ];then
            ejabberdctl restore $JABBERDSAVFILE
	else
            echo "ejabberd est arrêté : impossible de restaurer sa base"
	fi
    fi

}

## Restauration des paquets ##
postrestorepkg(){
    if [ $MODULE == "eclair" ]
    then
        dpkg --set-selections < /home/sauv_paquet.txt
        apt-get dselect-upgrade -y --force-yes
	apt-get clean
    	rm -f /home/sauv_paquet.txt
    fi
}

## Fichiers ##
postrestore(){
    postrestorepkg
    # Gestion du SID,
    if [ -f "$SIDSAVEFILE" ]
    then
        cat $SIDSAVEFILE | xargs net setlocalsid
    fi
    if [ "$MODULE" == "scribe" ]
    then
	#les uidNumbers changent d'une version à l'autre
	chown sympa:sympa /etc/mail/sympa_aliases
	chown mysql:mysql /var/lib/mysql/ -R
    fi
    echo
    echo "*** Restauration terminée ***"
    echo
    exit 0
}

## Restauration complète ##
postrestoreall(){
    #on restaure les acl ici
#    postrestoreacl
    echo "################################"
    echo "# La restauration est terminée #"
    echo "#    Appuyez sur Ctrl+C et     #"
    echo "#   Lancez 'reconfigure' !!!   #"
    echo "################################"
}


case $1 in
  prebackupldap)
      prebackupldap
      ;;
  postbackupldap)
      postbackupldap
      ;;
  prebackupmysql)
      prebackupmysql
      ;;
  postbackupmysql)
      postbackupmysql
      ;;
  prebackupquota)
      prebackupquota
      ;;
  postbackupquota)
      postbackupquota
      ;;
#  prebackupacl)
#      prebackupacl
#      ;;
#  postbackupacl)
#      postbackupacl
#      ;;
  prebackupejabberd)
      prebackupejabberd
      ;;
  postbackupejabberd)
      postbackupejabberd
      ;;
  prebackup)
      prebackup
      ;;
  postbackup)
      postbackup
      ;;
  postbackuperr)
      postbackuperr
      ;;
  precatalog)
      precatalog
      ;;
  postcatalog)
      postcatalog
      ;;
  postcatalogerr)
      postcatalogerr
      ;;
  prerestoreall)
      prerestoreall
      ;;
  postrestoreldap)
      postrestoreldap
      ;;
  postrestoremysql)
      postrestoremysql
      ;;
  postrestorequota)
      postrestorequota
      ;;
#  postrestoreacl)
#      postrestoreacl
#      ;;
  postrestoreejabberd)
      postrestoreejabberd
      ;;
  postrestore)
      postrestore
      ;;
  postrestoreall)
      postrestoreall
      ;;
  servicestart)
      servicestart
      ;;
  servicestop)
      servicestop
      ;;
  lock)
      addlock
      ;;
  unlock)
      dellock
      ;;
*)
      echo "Argument $* inconnu"
      echo "Usage : "$0" prebackupldap | prebackupmysql | prebackupquota | prebackupejabberd | prebackup"
      echo "Usage : "$0" postbackupldap | postbackupmysql | postbackupquota | postbackupejabberd |ppostbackup | postbackuperr"
      echo "Usage : "$0" precatalog | postcatalog"
      echo "Usage : "$0" prerestoreall"
      echo "Usage : "$0" postrestoreldap | postrestoremysql | postrestorequota | postrestoreejabberd | postrestore | postrestoreall"
      echo "Usage : "$0" servicestart | servicestop"
      echo "Usage : "$0" lock | unlock"
      exit 1
esac
