#!/bin/bash
# Utilitaire permettant de monter/démonter le support de sauvegarde
# défini dans l'EAD

REPERTOIRE='/var/sauvegardes'
VERSION=`cat /etc/eole/version`
MODULE=`echo $VERSION | cut -d '-' -f 1`
SUPPORT=`/usr/share/eole/bacula/baculasupport.py -l`

# chemin des fichiers selon le module
if [ "$MODULE" == "scribe" ]
then
    FICH_CONF='/var/www/ead/config/bacula-distant.txt'
    FICH_CONF_USB='/var/www/ead/config/bacula-usb.txt'
elif [ "$MODULE" == "horus" ]
then
    FICH_CONF='/var/www/ead/tmp/bacula-distant.txt'
    FICH_CONF_USB='/var/www/ead/tmp/bacula-usb.txt'
else
    FICH_CONF='/usr/share/ead2/backend/tmp/bacula-distant.txt'
    FICH_CONF_USB='/usr/share/ead2/backend/tmp/bacula-usb.txt'
fi

demontage(){
    # pas de démontage dans eolevz
    if [ ! -e /etc/sysconfig/eole/eolevz ]; then
        #monté plusieurs fois ...
        cpt=`mount |grep $REPERTOIRE -c`
        if [ "$cpt" != 0 ]
        then
        for i in `seq $cpt`; do
            echo "Démontage de $REPERTOIRE"
            /bin/umount $REPERTOIRE > /dev/null
        done
        fi
    fi
}

test_distant(){
    # test accès au pc distant
    tcpcheck 2 $1:139|grep -q alive
    if [ "$?" -ne "0" ]
    then
        tcpcheck 2 $1:445|grep -q alive
        if [ "$?" -ne "0" ]
        then
            echo "La machine $1 n'est pas accessible sur les ports 139 et 445"
            exit 1
        fi
    fi
}

distant(){
    demontage
    if [ -e ${FICH_CONF} ]
    then
        Param=(` /bin/cat ${FICH_CONF}`)
        pc_distant=${Param[0]}
        ip_pc_distant=${Param[1]}
        user=${Param[2]}
        pass=${Param[3]}
    fi
    if [  -n  "$pc_distant"  ]
    then
        test_distant $ip_pc_distant
        if [ -n "$pass" ]
        then
            /bin/mount -t smbfs -o username=$user,password=$pass,ip=$ip_pc_distant $pc_distant $REPERTOIRE
            if [ $? -ne 0 ]
            then
                echo
                echo "######################################################"
                echo "# Erreur : Montage $pc_distant, $user Impossible 1"
                echo "######################################################"
                echo
                exit 1
            else
                echo "# Montage $pc_distant, $user OK #"
            fi
        else
            /bin/mount -t smbfs -o password="",ip=$ip_pc_distant $pc_distant $REPERTOIRE
            if [ $? -ne 0 ]
            then
                echo
                echo "######################################################"
                echo "# Erreur : Montage $pc_distant Impossible 2"
                echo "######################################################"
                echo
                exit 1
            else
                echo "# Montage $pc_distant (PC DISTANT) OK #"
            fi
        fi
    else
        echo
        echo "######################################################"
        echo "# Vous devez renseigner vos paramètres de PC distant"
        echo "######################################################"
        echo
        exit 1
    fi
}

usb(){
    demontage
    if [ -e ${FICH_CONF_USB} ]
    then
        usb_device=`cat ${FICH_CONF_USB}|head -n1|awk '{print $1}'`
    fi
    if [  -n  "$usb_device"  ]
    then
        if [ -z $1 ];then
            nb=40
        else
            nb=2
        fi
        for i in `seq 1 $nb` # pour les disques qui se mettent en veille
        do
            /bin/mount $usb_device $REPERTOIRE
            ret=$?
            [ "$ret" -eq "0" ] && break
            echo "Problème de montage (essai $i/$nb)" #2 minutes
            [ $i -ne $nb ] && sleep 3
        done
        if [ $ret -ne 0 ]
        then
            echo
            echo "######################################################"
            echo "Erreur : Montage $usb_device Impossible (USB)"
            echo "######################################################"
            echo
            exit 1
        else
            echo "# Montage $usb_device (USB) OK #"
        fi
    else
        echo
        echo "######################################################"
        echo "#    Vous devez renseigner votre type de support     #"
        echo "######################################################"
        echo
        exit 1
    fi
}

pre(){
    if [ "$SUPPORT" == "distant" ]
    then
        distant
    elif [ "$SUPPORT" == "usb" ]
    then
        usb $1
    elif [ "$SUPPORT" == "bande" ]
    then
        echo "Support $SUPPORT utilisé, aucun montage"
    else
        echo "Aucun support de sauvegarde configuré"
    fi
}

post(){
    if [ "$SUPPORT" == "bande" ]
    then
        echo "Support $SUPPORT utilisé, aucun démontage"
    else
        demontage
    fi
}

case $1 in
  pre)
      pre
      ;;
  pretest)
      pre 'test'
      ;;
  post)
      post
      ;;
*)
      echo "Usage : "$0" pre|pretest|post"
      exit 1
esac
