#!/bin/bash
REPERTOIRE='/var/sauvegardes'
VERSION=`cat /etc/eole/version`
MODULE=`echo $VERSION | cut -d '-' -f 1`
BACULA_DB_VER=11

. ParseDico

#monté plusieurs fois ...
demontage(){
    #pas de démontage dans eolevz
    if [ ! -e /etc/sysconfig/eole/eolevz ]; then
	    #monté plusieurs fois ...
	    cpt=`mount |grep $REPERTOIRE -c`
	    if [ "$cpt" != 0 ]
	    then
		for i in `seq $cpt`
		do
		    echo "Démontage de $REPERTOIRE"
		    /bin/umount $REPERTOIRE > /dev/null 2>&1
		done
	    fi
    fi
}

resto_dist(){
    echo "Nom NETBIOS de la station de sauvegarde Bacula"
    read pc_distant
    echo "Adresse IP de la station de sauvegarde Bacula"
    read ip_pc_distant
    echo "Nom du partage"
    read partage
    echo "Nom de l'utilisateur sinon rien"
    read user
    echo "Mot de passe sinon rien"
    read pass
    umount $REPERTOIRE &>/dev/null
    if [ -z $user ]
    then
    	mount -t smbfs -o username="''",password="''",ip=$ip_pc_distant //$pc_distant/$partage $REPERTOIRE
    else
    	mount -t smbfs -o username="$user",password="$pass",ip=$ip_pc_distant //$pc_distant/$partage $REPERTOIRE

    fi
    if [ $? -ne 0 ]
    then
    	echo "Erreur : Montage $pc_distant Impossible"
    	exit 1
    fi
}

resto_usb(){
    echo "Quel est le chemin d'accès au périphérique (ex. : /dev/usb) ?"
    read periph_usb
    mount $periph_usb $REPERTOIRE
    if [ $? -ne 0 ]
    then
	echo "Erreur : Montage $periph_usb Impossible (USB)"
        exit 1
    fi
}

resto_scribe(){
    #ATTENTION AUX NUMEROS DE JOBS 1=RESTORE 2=RESTOREALL ETC.
    # restauration spécifique LDAP job n°3
    echo -e "restore FileSet=Complete Client=127.0.0.1-fd select current yes file=/home/sauv_ldap.ldif done\n3\n"|bconsole -c /etc/bacula/bconsole.conf
    # restauration spécifique MySQL job n°4
    echo -e "restore FileSet=Complete Client=127.0.0.1-fd select current yes file=/home/sauv_mysql.sql done\n4\n"|bconsole -c /etc/bacula/bconsole.conf
    # restauration spécifique Quotas job n°5
    echo -e "restore FileSet=Complete Client=127.0.0.1-fd select current yes file=/home/sauv_quota.txt done\n5\n"|bconsole -c /etc/bacula/bconsole.conf
    # restauration spécifique Acls job n°6
    #echo -e "restore FileSet=Complete Client=127.0.0.1-fd select current yes file=/home/sauv_acl.txt done\n6\n"|bconsole -c /etc/bacula/bconsole.conf
    # on ne veut pas restaurer LDAP MySQL QUOTA job n°2
    echo -e "restore FileSet=Complete Client=127.0.0.1-fd select current all yes\ncd home\nunmark sauv_ldap.ldif\nunmark sauv_mysql.sql\nunmark sauv_quota.txt\ndone\n2\n"|bconsole -c /etc/bacula/bconsole.conf
}

resto_horus(){
    # restauration spécifique LDAP job n°3
    echo -e "restore FileSet=Complete Client=127.0.0.1-fd select current yes file=/data/sauv_ldap.ldif done\n3\n"|bconsole -c /etc/bacula/bconsole.conf
    # restauration spécifique MySQL job n°4
    if [ "$mysql" != "non" ]
    then
	    echo -e "restore FileSet=Complete Client=127.0.0.1-fd select current yes file=/data/sauv_mysql.sql done\n4\n"|bconsole -c /etc/bacula/bconsole.conf
    fi
    # restauration spécifique Quotas job N°5
    echo -e "restore FileSet=Complete Client=127.0.0.1-fd select current yes file=/data/sauv_quota.txt done\n5\n"|bconsole -c /etc/bacula/bconsole.conf
    # restauration spécifique Acls job n°6
    #echo -e "restore FileSet=Complete Client=127.0.0.1-fd select current yes file=/data/sauv_acl.txt done\n6\n"|bconsole -c /etc/bacula/bconsole.conf
    # on ne veut pas restaurer LDAP MySQL QUOTA job n°2
    echo -e "restore FileSet=Complete Client=127.0.0.1-fd select current all yes\ncd data\nunmark sauv_ldap.ldif\nunmark sauv_mysql.sql\nunmark sauv_quota.txt\ndone\n2\n"|bconsole -c /etc/bacula/bconsole.conf
}

resto_eclair(){
    echo -e "restore FileSet=Complete Client=127.0.0.1-fd select current all yes\ndone\n1\n"|bconsole -c /etc/bacula/bconsole.conf
}

config_mail(){
    while [ "$mail" == "" ]
    do
        echo "Entrez l'adresse mail :"
        read mail
    done
    if [ "$passerelle_smtp" != "" ]
    then
        smtp=$passerelle_smtp
    elif [ "$passerelle_smtp_aca" != "" ]
    then
        smtp=$passerelle_smtp_aca
    else
        while [ "$smtp" == "" ]
        do
            echo "Entrez l'adresse du serveur SMTP :"
            read smtp
        done
    fi
    /usr/share/eole/bacula/baculamessage.py -s $smtp -o $mail
    if [ "$?" -ne "0" ]
    then
        echo "Paramétrage du mail echoué, abandon."
	exit 1
    fi
}

echo "Voulez-vous configurer l'envoi d'un mail en fin de restauration [o/N] ?"
read rep
if [ "$rep" == "o" -o  "$rep" == "oui" -o "$rep" == "O" -o "$rep" == "OUI" ]
then
	config_mail
fi

if [ ! -e /etc/sysconfig/eole/eolevz ]; then
	demontage
	echo "Type de support ("distant" ou "usb"):"
	read type_support
	if [ "$type_support" == "distant" ]
	then
	    resto_dist
	elif [ "$type_support" == "usb" ]
	then
	    resto_usb
	else
	    echo "Mauvais type de support \"$type_support\""
	    exit 1
	fi
fi
# ré-initialisation de la base
if [ ! -e "$REPERTOIRE/$VERSION-bacula.sql" ]; then
	echo \"$REPERTOIRE/$VERSION-bacula.sql\" introuvable.
	echo Abandon !
	exit 1
fi
/etc/init.d/bacula-director stop
rm -f /var/lib/bacula/bacula.db
/usr/bin/sqlite3 /var/lib/bacula/bacula.db < $REPERTOIRE/$VERSION-bacula.sql
db_ver=`echo "SELECT VersionId FROM Version;"|sqlite3 /var/lib/bacula/bacula.db`
if [ "$db_ver" -lt "$BACULA_DB_VER" ]
then
	/usr/share/bacula-director/update_sqlite3_tables
fi
/etc/init.d/bacula-director start
sleep 3

if [ $MODULE == "horus" ]
then
    resto_horus
elif [ $MODULE == "scribe" ]
then
    resto_scribe
elif [ $MODULE == "eclair" ]
then
    resto_eclair
else
    echo Module $MODULE inconnu
    exit 1
fi

# affichage du log
echo "######################################################"
echo "Patientez ...."
echo ""
touch /var/log/bacula/bacula.log
tail -f /var/log/bacula/bacula.log -n0

